@@ -1,11 +1,11 @@
 #![no_std]
 
 pub mod error;
-pub mod group;
 pub mod refer;
+pub mod ring;
 pub mod state;
 
 pub use error::Error;
-pub use group::*;
 pub use refer::*;
+pub use ring::*;
 pub use state::*;
